
Barra Risk Model for China A market
===================================

This is a self-build project for studying purpose only.
Any commercial usage of this project is banned.

dependent package
-----------------
- python 3.5
- pandas 0.23.0
- spyder 3.2.8
